@@ -1,7 +1,6 @@
 from collections import namedtuple
 
 from .gallery import gallery_chains
-from .transform import transform_chains
 from .upload import upload_chains
 
 __all__ = ['generic']
@@ -30,13 +29,11 @@ Generic = namedtuple(
     'Generic',
     [
         'gallery',
-        'transform',
         'upload'
     ])
 
 # Create an instance of Generic containing all the generic views
 generic = Generic(
     gallery=gallery_chains,
-    transform=transform_chains,
     upload=upload_chains
     )
