@@ -347,7 +347,8 @@ def store_assets(state):
     if hasattr(document, 'logged_update'):
         document.logged_update(
             state.manage_user,
-            {state.gallery_field: [a.to_json_type() for a in state.assets]}
+            {state.gallery_field: [a.to_json_type() for a in state.assets]},
+            state.gallery_field
         )
 
     else:
